# Supported Sources & Destinations ingestr supports the following sources and destinations:

| Source | Destination
--- | --- | ---
Databases
Postgres | ✅ | ✅
BigQuery | ✅ | ✅
Snowflake | ✅ | ✅
Redshift | ✅ | ✅
Databricks | ✅ | ✅
DuckDB | ✅ | ✅
Microsoft SQL Server | ✅ | ✅
Local CSV file | ✅ | ✅
MongoDB | ✅ | ❌
Oracle | ✅ | ❌
SAP Hana | ✅ | ❌
SQLite | ✅ | ❌
MySQL | ✅ | ❌
Platforms
Gorgias | ✅ | ❌
Google Sheets | ✅ | ❌
Notion | ✅ | ❌
Shopify | ✅ | ❌

More to come soon!